Skip to main contentModule crypto
Source pub use types::*;pub use aad::*;pub use aead::*;pub use kdf::*;pub use nonce::*;pub use digest::*;
- aad
- aead
- src/crypto/aead.rs
AEAD interface for AES-256-GCM and ChaCha20-Poly1305.
- digest
- kdf
- crypto/kdf.rs
HKDF-based session key derivation from master key and header salt.
- nonce
- nonce/builder.rs
Deterministic nonce derivation from stream salt and frame index.
- types